@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -37,7 +37,7 @@ from .literals import (
     TextTransformationTypeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -155,6 +155,7 @@ __all__ = (
     "PutPermissionPolicyRequestRequestTypeDef",
     "RateBasedStatementManagedKeysIPSetTypeDef",
     "RateBasedStatementTypeDef",
+    "RegexMatchStatementTypeDef",
     "RegexPatternSetReferenceStatementTypeDef",
     "RegexPatternSetSummaryTypeDef",
     "RegexPatternSetTypeDef",
@@ -213,7 +214,7 @@ AllowActionTypeDef = TypedDict(
 AndStatementTypeDef = TypedDict(
     "AndStatementTypeDef",
     {
-        "Statements": List["StatementTypeDef"],
+        "Statements": Sequence[Dict[str, Any]],
     },
 )
 
@@ -238,7 +239,7 @@ ByteMatchStatementTypeDef = TypedDict(
     {
         "SearchString": Union[bytes, IO[bytes], StreamingBody],
         "FieldToMatch": "FieldToMatchTypeDef",
-        "TextTransformations": List["TextTransformationTypeDef"],
+        "TextTransformations": Sequence["TextTransformationTypeDef"],
         "PositionalConstraint": PositionalConstraintType,
     },
 )
@@ -247,7 +248,7 @@ CheckCapacityRequestRequestTypeDef = TypedDict(
     "CheckCapacityRequestRequestTypeDef",
     {
         "Scope": ScopeType,
-        "Rules": List["RuleTypeDef"],
+        "Rules": Sequence["RuleTypeDef"],
     },
 )
 
@@ -282,14 +283,14 @@ _RequiredCreateIPSetRequestRequestTypeDef = TypedDict(
         "Name": str,
         "Scope": ScopeType,
         "IPAddressVersion": IPAddressVersionType,
-        "Addresses": List[str],
+        "Addresses": Sequence[str],
     },
 )
 _OptionalCreateIPSetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateIPSetRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -314,14 +315,14 @@ _RequiredCreateRegexPatternSetRequestRequestTypeDef = TypedDict(
     {
         "Name": str,
         "Scope": ScopeType,
-        "RegularExpressionList": List["RegexTypeDef"],
+        "RegularExpressionList": Sequence["RegexTypeDef"],
     },
 )
 _OptionalCreateRegexPatternSetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRegexPatternSetRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -355,9 +356,9 @@ _OptionalCreateRuleGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRuleGroupRequestRequestTypeDef",
     {
         "Description": str,
-        "Rules": List["RuleTypeDef"],
-        "Tags": List["TagTypeDef"],
-        "CustomResponseBodies": Dict[str, "CustomResponseBodyTypeDef"],
+        "Rules": Sequence["RuleTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
+        "CustomResponseBodies": Mapping[str, "CustomResponseBodyTypeDef"],
     },
     total=False,
 )
@@ -390,9 +391,9 @@ _OptionalCreateWebACLRequestRequestTypeDef = TypedDict(
     "_OptionalCreateWebACLRequestRequestTypeDef",
     {
         "Description": str,
-        "Rules": List["RuleTypeDef"],
-        "Tags": List["TagTypeDef"],
-        "CustomResponseBodies": Dict[str, "CustomResponseBodyTypeDef"],
+        "Rules": Sequence["RuleTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
+        "CustomResponseBodies": Mapping[str, "CustomResponseBodyTypeDef"],
     },
     total=False,
 )
@@ -423,7 +424,7 @@ CustomHTTPHeaderTypeDef = TypedDict(
 CustomRequestHandlingTypeDef = TypedDict(
     "CustomRequestHandlingTypeDef",
     {
-        "InsertHeaders": List["CustomHTTPHeaderTypeDef"],
+        "InsertHeaders": Sequence["CustomHTTPHeaderTypeDef"],
     },
 )
 
@@ -445,7 +446,7 @@ _OptionalCustomResponseTypeDef = TypedDict(
     "_OptionalCustomResponseTypeDef",
     {
         "CustomResponseBodyKey": str,
-        "ResponseHeaders": List["CustomHTTPHeaderTypeDef"],
+        "ResponseHeaders": Sequence["CustomHTTPHeaderTypeDef"],
     },
     total=False,
 )
@@ -591,11 +592,11 @@ FieldToMatchTypeDef = TypedDict(
     {
         "SingleHeader": "SingleHeaderTypeDef",
         "SingleQueryArgument": "SingleQueryArgumentTypeDef",
-        "AllQueryArguments": Dict[str, Any],
-        "UriPath": Dict[str, Any],
-        "QueryString": Dict[str, Any],
-        "Body": Dict[str, Any],
-        "Method": Dict[str, Any],
+        "AllQueryArguments": Mapping[str, Any],
+        "UriPath": Mapping[str, Any],
+        "QueryString": Mapping[str, Any],
+        "Body": Mapping[str, Any],
+        "Method": Mapping[str, Any],
         "JsonBody": "JsonBodyTypeDef",
     },
     total=False,
@@ -641,7 +642,7 @@ ForwardedIPConfigTypeDef = TypedDict(
 GeoMatchStatementTypeDef = TypedDict(
     "GeoMatchStatementTypeDef",
     {
-        "CountryCodes": List[CountryCodeType],
+        "CountryCodes": Sequence[CountryCodeType],
         "ForwardedIPConfig": "ForwardedIPConfigTypeDef",
     },
     total=False,
@@ -713,8 +714,8 @@ GetPermissionPolicyResponseTypeDef = TypedDict(
     },
 )
 
-GetRateBasedStatementManagedKeysRequestRequestTypeDef = TypedDict(
-    "GetRateBasedStatementManagedKeysRequestRequestTypeDef",
+_RequiredGetRateBasedStatementManagedKeysRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRateBasedStatementManagedKeysRequestRequestTypeDef",
     {
         "Scope": ScopeType,
         "WebACLName": str,
@@ -722,6 +723,21 @@ GetRateBasedStatementManagedKeysRequestRequestTypeDef = TypedDict(
         "RuleName": str,
     },
 )
+_OptionalGetRateBasedStatementManagedKeysRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRateBasedStatementManagedKeysRequestRequestTypeDef",
+    {
+        "RuleGroupRuleName": str,
+    },
+    total=False,
+)
+
+
+class GetRateBasedStatementManagedKeysRequestRequestTypeDef(
+    _RequiredGetRateBasedStatementManagedKeysRequestRequestTypeDef,
+    _OptionalGetRateBasedStatementManagedKeysRequestRequestTypeDef,
+):
+    pass
+
 
 GetRateBasedStatementManagedKeysResponseTypeDef = TypedDict(
     "GetRateBasedStatementManagedKeysResponseTypeDef",
@@ -934,8 +950,8 @@ class JsonBodyTypeDef(_RequiredJsonBodyTypeDef, _OptionalJsonBodyTypeDef):
 JsonMatchPatternTypeDef = TypedDict(
     "JsonMatchPatternTypeDef",
     {
-        "All": Dict[str, Any],
-        "IncludedPaths": List[str],
+        "All": Mapping[str, Any],
+        "IncludedPaths": Sequence[str],
     },
     total=False,
 )
@@ -1317,7 +1333,7 @@ _OptionalManagedRuleGroupStatementTypeDef = TypedDict(
     "_OptionalManagedRuleGroupStatementTypeDef",
     {
         "Version": str,
-        "ExcludedRules": List["ExcludedRuleTypeDef"],
+        "ExcludedRules": Sequence["ExcludedRuleTypeDef"],
         "ScopeDownStatement": "StatementTypeDef",
     },
     total=False,
@@ -1409,7 +1425,7 @@ NotStatementTypeDef = TypedDict(
 OrStatementTypeDef = TypedDict(
     "OrStatementTypeDef",
     {
-        "Statements": List["StatementTypeDef"],
+        "Statements": Sequence["StatementTypeDef"],
     },
 )
 
@@ -1417,7 +1433,7 @@ OverrideActionTypeDef = TypedDict(
     "OverrideActionTypeDef",
     {
         "Count": "CountActionTypeDef",
-        "None": Dict[str, Any],
+        "None": Mapping[str, Any],
     },
     total=False,
 )
@@ -1450,7 +1466,7 @@ _OptionalPutManagedRuleSetVersionsRequestRequestTypeDef = TypedDict(
     "_OptionalPutManagedRuleSetVersionsRequestRequestTypeDef",
     {
         "RecommendedVersion": str,
-        "VersionsToPublish": Dict[str, "VersionToPublishTypeDef"],
+        "VersionsToPublish": Mapping[str, "VersionToPublishTypeDef"],
     },
     total=False,
 )
@@ -1498,7 +1514,7 @@ _RequiredRateBasedStatementTypeDef = TypedDict(
 _OptionalRateBasedStatementTypeDef = TypedDict(
     "_OptionalRateBasedStatementTypeDef",
     {
-        "ScopeDownStatement": Dict[str, Any],
+        "ScopeDownStatement": "StatementTypeDef",
         "ForwardedIPConfig": "ForwardedIPConfigTypeDef",
     },
     total=False,
@@ -1511,12 +1527,21 @@ class RateBasedStatementTypeDef(
     pass
 
 
+RegexMatchStatementTypeDef = TypedDict(
+    "RegexMatchStatementTypeDef",
+    {
+        "RegexString": str,
+        "FieldToMatch": "FieldToMatchTypeDef",
+        "TextTransformations": Sequence["TextTransformationTypeDef"],
+    },
+)
+
 RegexPatternSetReferenceStatementTypeDef = TypedDict(
     "RegexPatternSetReferenceStatementTypeDef",
     {
         "ARN": str,
         "FieldToMatch": "FieldToMatchTypeDef",
-        "TextTransformations": List["TextTransformationTypeDef"],
+        "TextTransformations": Sequence["TextTransformationTypeDef"],
     },
 )
 
@@ -1558,7 +1583,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -1582,7 +1607,7 @@ _RequiredRuleGroupReferenceStatementTypeDef = TypedDict(
 _OptionalRuleGroupReferenceStatementTypeDef = TypedDict(
     "_OptionalRuleGroupReferenceStatementTypeDef",
     {
-        "ExcludedRules": List["ExcludedRuleTypeDef"],
+        "ExcludedRules": Sequence["ExcludedRuleTypeDef"],
     },
     total=False,
 )
@@ -1657,7 +1682,7 @@ _OptionalRuleTypeDef = TypedDict(
     {
         "Action": "RuleActionTypeDef",
         "OverrideAction": "OverrideActionTypeDef",
-        "RuleLabels": List["LabelTypeDef"],
+        "RuleLabels": Sequence["LabelTypeDef"],
     },
     total=False,
 )
@@ -1714,7 +1739,7 @@ SizeConstraintStatementTypeDef = TypedDict(
         "FieldToMatch": "FieldToMatchTypeDef",
         "ComparisonOperator": ComparisonOperatorType,
         "Size": int,
-        "TextTransformations": List["TextTransformationTypeDef"],
+        "TextTransformations": Sequence["TextTransformationTypeDef"],
     },
 )
 
@@ -1722,7 +1747,7 @@ SqliMatchStatementTypeDef = TypedDict(
     "SqliMatchStatementTypeDef",
     {
         "FieldToMatch": "FieldToMatchTypeDef",
-        "TextTransformations": List["TextTransformationTypeDef"],
+        "TextTransformations": Sequence["TextTransformationTypeDef"],
     },
 )
 
@@ -1743,6 +1768,7 @@ StatementTypeDef = TypedDict(
         "NotStatement": Dict[str, Any],
         "ManagedRuleGroupStatement": Dict[str, Any],
         "LabelMatchStatement": "LabelMatchStatementTypeDef",
+        "RegexMatchStatement": "RegexMatchStatementTypeDef",
     },
     total=False,
 )
@@ -1760,7 +1786,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1792,7 +1818,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1802,7 +1828,7 @@ _RequiredUpdateIPSetRequestRequestTypeDef = TypedDict(
         "Name": str,
         "Scope": ScopeType,
         "Id": str,
-        "Addresses": List[str],
+        "Addresses": Sequence[str],
         "LockToken": str,
     },
 )
@@ -1857,7 +1883,7 @@ _RequiredUpdateRegexPatternSetRequestRequestTypeDef = TypedDict(
         "Name": str,
         "Scope": ScopeType,
         "Id": str,
-        "RegularExpressionList": List["RegexTypeDef"],
+        "RegularExpressionList": Sequence["RegexTypeDef"],
         "LockToken": str,
     },
 )
@@ -1899,8 +1925,8 @@ _OptionalUpdateRuleGroupRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateRuleGroupRequestRequestTypeDef",
     {
         "Description": str,
-        "Rules": List["RuleTypeDef"],
-        "CustomResponseBodies": Dict[str, "CustomResponseBodyTypeDef"],
+        "Rules": Sequence["RuleTypeDef"],
+        "CustomResponseBodies": Mapping[str, "CustomResponseBodyTypeDef"],
     },
     total=False,
 )
@@ -1935,8 +1961,8 @@ _OptionalUpdateWebACLRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateWebACLRequestRequestTypeDef",
     {
         "Description": str,
-        "Rules": List["RuleTypeDef"],
-        "CustomResponseBodies": Dict[str, "CustomResponseBodyTypeDef"],
+        "Rules": Sequence["RuleTypeDef"],
+        "CustomResponseBodies": Mapping[str, "CustomResponseBodyTypeDef"],
     },
     total=False,
 )
@@ -2020,6 +2046,6 @@ XssMatchStatementTypeDef = TypedDict(
     "XssMatchStatementTypeDef",
     {
         "FieldToMatch": "FieldToMatchTypeDef",
-        "TextTransformations": List["TextTransformationTypeDef"],
+        "TextTransformations": Sequence["TextTransformationTypeDef"],
     },
 )
